@@ -88,6 +88,9 @@ void     gnome_rr_output_info_set_primary (GnomeRROutputInfo *self, gboolean pri
 int gnome_rr_output_info_get_preferred_width  (GnomeRROutputInfo *self);
 int gnome_rr_output_info_get_preferred_height (GnomeRROutputInfo *self);
 
+gboolean gnome_rr_output_info_get_underscanning (GnomeRROutputInfo *self);
+void     gnome_rr_output_info_set_underscanning (GnomeRROutputInfo *self, gboolean underscanning);
+
 typedef struct _GnomeRRConfig GnomeRRConfig;
 typedef struct _GnomeRRConfigClass GnomeRRConfigClass;
 typedef struct _GnomeRRConfigPrivate GnomeRRConfigPrivate;
